@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2008, 2010, 2012-2014 Richard Dymond (rjdymond@gmail.com)
+# Copyright 2008, 2010, 2012-2015 Richard Dymond (rjdymond@gmail.com)
 #
 # This file is part of Pyskool.
 #
@@ -26,17 +26,18 @@ import pickle
 import pygame
 import random
 import time
-from cast import Cast
-from character import Character
-from skool import Skool
-from graphics import Screen, Gallery
-from sound import Beeper
-from input import Keyboard
-from iniparser import IniParser
-import skoolbuilder
-import keys
-import items
-import debug
+
+from .cast import Cast
+from .character import Character
+from .skool import Skool
+from .graphics import Screen, Gallery
+from .sound import Beeper
+from .input import Keyboard
+from .iniparser import IniParser
+from . import skoolbuilder
+from . import keys
+from . import items
+from . import debug
 
 #: Menu operation: Resume.
 RESUME = 'RESUME'
@@ -97,7 +98,6 @@ class Game:
 
         builder = skoolbuilder.SkoolBuilder(ini_dir)
         builder.sections['ExtraConfig'] = options.config or []
-        builder.section_names.append('ExtraConfig')
         config = builder.get_config('[A-Za-z]+Config')
         self.scale = options.scale or config.get('Scale', 2)
         self.cheat = options.cheat or config.get('Cheat', 0)
@@ -114,7 +114,8 @@ class Game:
                 return
             debug.log('Unable to restore from %s: file not found' % sav_file)
 
-        gallery = Gallery(images_dir, config, self.scale, builder.get_config(skoolbuilder.IMAGES))
+        image_set = config.get('ImageSet', 'original')
+        gallery = Gallery(images_dir, image_set, self.scale, builder.get_config(skoolbuilder.IMAGES))
         title_prefix = 'Pyskool %s: ' % version
         self.screen = Screen(config, gallery, title_prefix)
         self.beeper = Beeper(sounds_dir, config)
@@ -357,16 +358,15 @@ class Game:
 
     def _take_screenshot(self):
         """Take a screenshot."""
-        img_format = 'bmp' if pygame.version.vernum < (1, 8) else 'png'
         timestamp = time.strftime('%Y%m%d-%H%M%S')
-        img_fname = '%s-%03i.%s' % (timestamp, self.screenshot, img_format)
-        scrshot_dir = os.path.join(*self.skool.screenshot_dir.split('/'))
+        img_fname = '{}-{:03d}.png'.format(timestamp, self.screenshot)
+        scrshot_dir = self.skool.screenshot_dir
         if not os.path.isdir(scrshot_dir):
             os.makedirs(scrshot_dir)
         img_path = os.path.join(scrshot_dir, img_fname)
         self.screen.take_screenshot(img_path)
         self.screenshot += 1
-        debug.log('Took screenshot: %s' % img_path)
+        debug.log('Took screenshot: {}'.format(img_path))
 
     def play(self):
         """Start the game and enter the main loop."""
@@ -400,11 +400,11 @@ class Game:
 
         :return: `True` if the game is quitting, `False` otherwise.
         """
-        if self.keyboard.was_pressed(keys.FULL_SCREEN):
+        if self.keyboard.was_pressed(keys.FULL_SCREEN, force_check=True):
             pygame.display.toggle_fullscreen()
             return False
 
-        if self.keyboard.was_pressed(keys.SCREENSHOT):
+        if self.keyboard.was_pressed(keys.SCREENSHOT, force_check=True):
             self._take_screenshot()
 
         if self.menu:
@@ -466,13 +466,13 @@ class Game:
         self.skool.draw()
         self.skool.scroll(self.scroll, self.clock)
 
-        if self.keyboard.was_pressed(keys.MENU):
+        if self.keyboard.was_pressed(keys.MENU, force_check=True):
             self.menu = self.menus['Main']
             self.menu.reset()
             self.screen.draw_menu(self.menu)
-        elif self.keyboard.was_pressed(keys.SAVE):
+        elif self.keyboard.was_pressed(keys.SAVE, force_check=True):
             self._save_game()
-        elif self.keyboard.was_pressed(keys.LOAD):
+        elif self.keyboard.was_pressed(keys.LOAD, force_check=True):
             self._load_last()
 
         return False
@@ -522,15 +522,15 @@ class Menu:
     def get_operation(self, keyboard):
         """Return the operation to perform (which may be `None`)."""
         operation = None
-        if keyboard.was_pressed(keys.MENU_EXIT):
+        if keyboard.was_pressed(keys.MENU_EXIT, force_check=True):
             return RESUME
-        if keyboard.was_pressed(keys.MENU_PREV):
+        if keyboard.was_pressed(keys.MENU_PREV, force_check=True):
             self.selected_index -= 1
             operation = UPDATE
-        elif keyboard.was_pressed(keys.MENU_NEXT):
+        elif keyboard.was_pressed(keys.MENU_NEXT, force_check=True):
             self.selected_index += 1
             operation = UPDATE
-        elif keyboard.was_pressed(keys.MENU_EXEC):
+        elif keyboard.was_pressed(keys.MENU_EXEC, force_check=True):
             operation = self.items[self.selected_index][0]
         self.selected_index = self.selected_index % len(self.items)
         return operation
